@@ -34,6 +34,7 @@
 #' 
 #' @return A list of class \code{proptest}. The print method lays out the information in an easy-to-read
 #' format. 
+#' \describe{
 #' \item{tab}{A formatted table of descriptive and inferential results (total number of observations,
 #' number of missing observations, sample proportion, standard error of the proportion estimate), 
 #' along with a confidence interval for the underlying proportion.}
@@ -45,7 +46,7 @@
 #' \item{var2}{The user-supplied second data vector. }
 #' \item{by}{The user-supplied stratification variable.}
 #' \item{par}{A vector of information about the type of test (null hypothesis, alternative hypothesis, etc.)}
-
+#' }
 #' 
 #' @seealso \code{\link[stats]{prop.test}}
 #' @examples
@@ -187,10 +188,19 @@ proptest <- function (var1, var2 = NULL, by = NULL, exact = FALSE,
           binom <- stats::binom.test(x = sum(var1), n = length(var1), p = null.hypoth, 
                               alternative = alternative, conf.level = conf.level)
           se <- sqrt(est1*(1-est1)/length(var1))
-          cil <- as.numeric(format(min(binom$conf.int), 
-                                   digits = digits))
-          cih <- as.numeric(format(max(binom$conf.int), 
-                                   digits = digits))
+          if (alternative == "two.sided") {
+            cil <- as.numeric(format(min(binom$conf.int), 
+                                     digits = digits))
+            cih <- as.numeric(format(max(binom$conf.int), 
+                                     digits = digits))
+          } else {
+            ci_test <- stats::binom.test(x = sum(var1), n = length(var1), p = null.hypoth, 
+                                         alternative = "two.sided", conf.level = conf.level)
+            cil <- as.numeric(format(min(ci_test$conf.int), 
+                                     digits = digits))
+            cih <- as.numeric(format(max(ci_test$conf.int), 
+                                     digits = digits))
+          }
           se <- as.numeric(format(se, digits = digits))
           pval <- as.numeric(format(binom$p.value, 
                                     digits = digits))
