@@ -30,6 +30,7 @@
 #' 
 #' @return A list of class \code{proptesti}. The print method lays out the information in an easy-to-read
 #' format. 
+#' \describe{
 #' \item{tab}{A formatted table of descriptive and inferential results (total number of observations,
 #' sample proportion, standard error of the proportion estimate), 
 #' along with a confidence interval for the underlying proportion.}
@@ -38,6 +39,7 @@
 #' \item{pval}{the p-value
 #' for the test} 
 #' \item{par}{A vector of information about the type of test (null hypothesis, alternative hypothesis, etc.)}
+#' }
 #' 
 #' @examples
 #' # Two-sample test
@@ -114,10 +116,18 @@ proptesti <- function(x1, n1, x2 = NULL, n2 = NULL, exact = FALSE,
         zstat <- NULL
         pval <- as.numeric(format(test$p.value, 
                                   digits = digits))
-        cil <- as.numeric(format(min(test$conf.int), 
-                                 digits = digits))
-        cih <- as.numeric(format(max(test$conf.int), 
-                                 digits = digits))
+        if (alternative == "two.sided") {
+          cil <- as.numeric(format(min(test$conf.int), 
+                                   digits = digits))
+          cih <- as.numeric(format(max(test$conf.int), 
+                                   digits = digits))
+        } else {
+          ci_test <- stats::binom.test(x1, n1, p = null.hypoth, alternative = "two.sided", conf.level = conf.level)
+          cil <- as.numeric(format(min(ci_test$conf.int), 
+                                   digits = digits))
+          cih <- as.numeric(format(max(ci_test$conf.int), 
+                                   digits = digits))
+        }
         
       } else {
         test <- stats::prop.test(x1, n1, p = null.hypoth, alternative = alternative, conf.level = conf.level, correct = correct)
@@ -129,13 +139,14 @@ proptesti <- function(x1, n1, x2 = NULL, n2 = NULL, exact = FALSE,
                                  digits = digits))
         cih <- as.numeric(format(est1 + stats::qnorm(cl)*se1, 
                                  digits = digits))
-        if (alternative == "less") {
-          cil <- as.numeric(format(min(test$conf.int), 
-                                   digits = digits))
-        } else if (alternative == "greater") {
-          cih <- as.numeric(format(max(test$conf.int), 
-                                   digits = digits))
-        }
+        # as of issue 166, setting all CI's to be two sided even if test is one sided
+        # if (alternative == "less") {
+        #   cil <- as.numeric(format(min(test$conf.int), 
+        #                            digits = digits))
+        # } else if (alternative == "greater") {
+        #   cih <- as.numeric(format(max(test$conf.int), 
+        #                            digits = digits))
+        # }
       }
       est1 <- as.numeric(format(est1, digits = digits))
       se1 <- as.numeric(format(se1, digits = digits))
@@ -144,6 +155,13 @@ proptesti <- function(x1, n1, x2 = NULL, n2 = NULL, exact = FALSE,
                                             "]", sep = "")), ncol = 5)
       colnames(printMat) <- c("Variable", "Obs", "Mean", "Std. Error", paste0(conf.level*100, "% CI"))
       rownames(printMat) <- ""
+      # bound ci in [0, 1]
+      if (cil < 0) {
+        cil <- 0
+      } 
+      if (cih > 1) {
+        cih <- 1
+      }
     } else {
       twosamp <- TRUE
       est <- c(x1/n1, x2/n2, x1/n1- x2/n2)
@@ -176,6 +194,8 @@ proptesti <- function(x1, n1, x2 = NULL, n2 = NULL, exact = FALSE,
       names(printMat) <- c("Group", "Obs", 
                            "Mean", "Std. Err.", paste(conf.level * 100, "% CI", sep = ""))
       row.names(printMat) <- c("", " ", "  ")
+      cil[1:2] <- c(ifelse(cil[1] < 0, 0, cil[1]), ifelse(cil[2] < 0, 0, cil[2]))
+      cih[1:2] <- c(ifelse(cih[1] > 1, 1, cih[1]), ifelse(cih[2] > 1, 1, cih[2]))
     }
     par <- c(null.hypoth = null.hypoth, alternative = alternative, 
              conf.level = conf.level, exact = exact,  twosamp = twosamp,
